Crate lingo
lingo
0.2.0
All Items
Crate Items
Structs
Enums
Traits
Crate
lingo
Structs

Language
Iter
Lingo
Enums

Language
Traits

Stemmer
Stopwords
If this module is required the stopwords() method will be added to each language. This function will return a list of the most common words in each language or an empty HashSet if it is not supported by the ‘stopwords’ crate.